==> guile-2.0.12-1-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-31.go <==
GOOF----LE-4-2.04	      ] O 4       hC      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
f  srfi/srfi-31.scm	g  exportsS	g  rec	
 	g  set-current-module	 	 	g  cond-expand-provide	g  current-module	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any		g  each-any			 g  
syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-ATDoCNf$UpASD7yWFg43wp-1587	+*" 	,+### 	-f  l-ATDoCNf$UpASD7yWFg43wp-1592	.f  l-ATDoCNf$UpASD7yWFg43wp-1593	/f  l-ATDoCNf$UpASD7yWFg43wp-1594	0f  l-ATDoCNf$UpASD7yWFg43wp-1595	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-ATDoCNf$UpASD7yWFg43wp-1589	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-ATDoCNf$UpASD7yWFg43wp-1602	Ef  l-ATDoCNf$UpASD7yWFg43wp-1603	Ff  l-ATDoCNf$UpASD7yWFg43wp-1604	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5h  r   ]4	

5 4 >  "  G   4i4i5 >  "  G  4=? h    f   ]   C      ^       g  dummy
		 g  name		 g  formals			 g  body			  			   C@J  h   Q   ]   C    I       g  dummy
		 g  name		 g  expr			  			   CMN        h@   I  ]4 5$  @4 5$  @ 6       A      g  x
		9 g  tmp		9 g  tmp		"	9  g  filenamef  srfi/srfi-31.scm
		 		9  g  
documentationf  XReturn the given object, defined in a lexical environment where
NAME is bound to itself.g  
macro-typeg  syntax-rulesg  patternsg  nameg  formalsg  bodyg  ... g  nameg  expr   C5RCj       g  m
		(  g  filenamef  srfi/srfi-31.scm		
	)	
	.			6		&	;	
 	
   C6 

==> guile-2.0.13-1.1-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-31.go <==
GOOF----LE-4-2.04	      ] O 4       hC      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
f  srfi/srfi-31.scm	g  exportsS	g  rec	
 	g  set-current-module	 	 	g  cond-expand-provide	g  current-module	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any		g  each-any			 g  
syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-jyWi64VP4ybCEfCEYt8Ohc-1587	+*" 	,+### 	-f  l-jyWi64VP4ybCEfCEYt8Ohc-1592	.f  l-jyWi64VP4ybCEfCEYt8Ohc-1593	/f  l-jyWi64VP4ybCEfCEYt8Ohc-1594	0f  l-jyWi64VP4ybCEfCEYt8Ohc-1595	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-jyWi64VP4ybCEfCEYt8Ohc-1589	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-jyWi64VP4ybCEfCEYt8Ohc-1602	Ef  l-jyWi64VP4ybCEfCEYt8Ohc-1603	Ff  l-jyWi64VP4ybCEfCEYt8Ohc-1604	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5h  r   ]4	

5 4 >  "  G   4i4i5 >  "  G  4=? h    f   ]   C      ^       g  dummy
		 g  name		 g  formals			 g  body			  			   C@J  h   Q   ]   C    I       g  dummy
		 g  name		 g  expr			  			   CMN        h@   I  ]4 5$  @4 5$  @ 6       A      g  x
		9 g  tmp		9 g  tmp		"	9  g  filenamef  srfi/srfi-31.scm
		 		9  g  
documentationf  XReturn the given object, defined in a lexical environment where
NAME is bound to itself.g  
macro-typeg  syntax-rulesg  patternsg  nameg  formalsg  bodyg  ... g  nameg  expr   C5RCj       g  m
		(  g  filenamef  srfi/srfi-31.scm		
	)	
	.			6		&	;	
 	
   C6 
